'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.getSortData = getSortData;
exports.getDataSearch = getDataSearch;
exports.getSelectedByRows = getSelectedByRows;
exports.getSelectedByKey = getSelectedByKey;
exports.getSelectedKeys = getSelectedKeys;
exports.getSelectedIndex = getSelectedIndex;
exports.updateData = updateData;
exports.addColumnData = addColumnData;
exports.copyData = copyData;
exports.DelDataByKeys = DelDataByKeys;
exports.objectToArray = objectToArray;
/**
 * 数据排序并返回数据
 * @param  {[type]} data     [元数据]
 * @param  {[type]} sortName [排序字段名]
 * @param  {[type]} sortType [排序类型 升序/降序]
 * @return {[type]}          [description]
 */
function getSortData(data, sortName, sortType) {
	var sortData = [];
	data.map(function (item, index) {
		sortData.push(item);
	});
	return sortData.sort(compare(sortName, sortType));
}

/**
 * 排序规则
 * @param  {[type]} sortName [排序字段名]
 * @param  {[type]} sortType [排序类型 升序/降序]
 * @return {[type]}          [description]
 */
function compare(sortName, sortType) {
	return function (obj1, obj2) {
		if (formatNum(obj1[sortName]) < formatNum(obj2[sortName])) {
			if (sortType) {
				return -1;
			} else {
				return 1;
			}
		} else if (formatNum(obj1[sortName]) > formatNum(obj2[sortName])) {
			if (sortType) {
				return 1;
			} else {
				return -1;
			}
		} else {
			return 0;
		}
	};
}

/**
 * 转换数值类型
 * @param  {[type]} value [description]
 * @return {[type]}       [description]
 */
function formatNum(value) {
	if (!isNaN(value)) {
		return parseInt(value);
	} else {
		return value;
	}
}

/**
 * 全局检索
 * @param  {[type]} keyword [description]
 * @param  {[type]} data    [description]
 * @return {[type]}         [description]
 */
function getDataSearch(keyword, data) {
	keyword = keyword.replace(/(^\s*)|(\s*$)/g, '');

	//搜索关键字为空的时候显示所有的数据
	if (!keyword) {
		return data;
	}

	var items = data.filter(function (item, i, array) {
		var arr = [];
		var flag = false;
		for (var key in item) {
			arr.push(item[key]);
		}

		for (var i = 0; i < arr.length; i++) {
			var str = arr[i].toString().toLowerCase();
			if (str.indexOf(keyword.toLowerCase()) >= 0) {
				flag = true;
				break;
			}
		}

		if (flag) {
			return item;
		}
	});

	return items;
}

/**
 * 查找勾选的数据
 * @param  {[type]} data         [description]
 * @param  {[type]} selectedRows [description]
 * @return {[type]}              [description]
 */
function getSelectedByRows(data, selectedRows) {
	var selectedRowsDatas = [];

	selectedRows.map(function (key, index) {
		for (var i = 0; i < data.length; i++) {
			if (i == key) {
				selectedRowsDatas.push(data[i]);
				break;
			}
		}
	});
	return selectedRowsDatas;
}

/**
 * 根据key查找数据
 * @param  {[type]} data         [元数据]
 * @param  {[type]} selectedKeys [当前数据的key]
 * @return {[type]}              [description]
 */
function getSelectedByKey(data, selectedKeys) {
	var rows = [];
	selectedKeys.map(function (key, index) {
		for (var i = 0; i < data.length; i++) {
			if (data[i].key === key) {
				rows.push(data[i]);
			}
		}
	});
	return rows;
}

/**
 * 查找勾选的key
 * @param  {[type]} data         [description]
 * @param  {[type]} selectedRows [description]
 * @return {[type]}              [description]
 */
function getSelectedKeys(data, selectedRows) {
	var keyRows = [];

	selectedRows.map(function (key, index) {
		for (var i = 0; i < data.length; i++) {
			if (i == key) {
				keyRows.push(data[i].key);
				break;
			}
		}
	});

	return keyRows;
}

/**
 * 根据key获取当前数据列表的下标
 * @param  {[type]} data        [description]
 * @param  {[type]} selectedKey [description]
 * @return {[type]}             [description]
 */
function getSelectedIndex(data, selectedKey) {
	var keyIndex = [];

	selectedKey.map(function (key, index) {
		for (var i = 0; i < data.length; i++) {
			if (data[i].key == key) {
				keyIndex.push(i);
				break;
			}
		}
	});

	return keyIndex;
}

/**
 * 修改数据
 * @param  {[type]} data         [元数据]
 * @param  {[type]} filterData   [显示数据]
 * @param  {[type]} dataField    [列表名称]
 * @param  {[type]} row          [行数]
 * @param  {[type]} columnNumber [列数]
 * @param  {[type]} value        [值]
 * @return {[type]}              [description]
 */
function updateData(data, filterData, dataField, row, columnNumber, value) {
	var keyName = objectToArray(dataField)[columnNumber - 1];
	var keyId = '';
	var item = null;
	for (var i = 0; i < filterData.length; i++) {
		if (i === row) {
			keyId = filterData[i].key;
			filterData[i][keyName] = value;
			item = filterData[i];
		}
	}

	data.map(function (item, index) {
		if (item.key === keyId) {
			item[keyName] = value;
		}
	});

	return { data: data, filterData: filterData, item: item };
}

/**
 * 添加一列
 * @param {[type]} data         [description]
 * @param {[type]} filterData   [description]
 * @param {[type]} dataField    [description]
 * @param {[type]} columnNumber [description]
 * @param {[type]} value        [description]
 */
function addColumnData(data, filterData, dataField, columnNumber, value) {
	var arrField = objectToArray(dataField);
	var keyName = arrField[columnNumber - 1];
	var newItem = {};
	arrField.map(function (item, index) {
		if (keyName === item) {
			newItem[keyName] = value;
		} else {
			newItem[item] = '';
		}
	});
	data.unshift(newItem);
	filterData.unshift(newItem);

	return { data: data, filterData: filterData, newItem: newItem };
}

/**
 * 获取数据所有的key数组
 * @param  {[type]} data [description]
 * @return {[type]}      [description]
 */
function getDataKeys(data) {
	return data.map(function (item, index) {
		return item.key;
	});
}

function getMaxKey(keys) {
	var maxNum = void 0;
	for (var i = 1; i < keys.length; i++) {
		if (i === 1) maxNum = keys[0];
		if (maxNum < keys[i]) {
			maxNum = keys[i];
		}
	}
	return maxNum;
}

/**
 * 复制数据
 * @param {[type]} data       [description]
 * @param {[type]} filterData [description]
 * @param {[type]} rows       [description]
 */
function copyData(data, filterData, rows) {
	var keys = getDataKeys(data);
	var maxKey = getMaxKey(keys);
	var copyRows = [];

	rows.map(function (item, index) {
		var newItem = Object.assign({}, item);
		newItem.key = ++maxKey;
		data.unshift(newItem);
		filterData.unshift(newItem);
		copyRows.push(newItem);
	});

	return { data: data, filterData: filterData, copyRows: copyRows };
}

/**
 * 根据key删除数据
 * @param {[type]} data       [description]
 * @param {[type]} filterData [description]
 * @param {[type]} keys       [description]
 */
function DelDataByKeys(data, filterData, keys) {
	for (var i = 0; i < keys.length; i++) {

		for (var j = 0; j < data.length; j++) {
			if (data[j].key === keys[i]) {
				data.splice(j, 1);
			}
		}

		for (var k = 0; k < filterData.length; k++) {
			if (filterData[k].key === keys[i]) {
				filterData.splice(k, 1);
			}
		}
	}
	return { data: data, filterData: filterData };
}

/**
 * 将对象名转换成数组
 * @param  {[type]} data [description]
 * @return {[type]}      [description]
 */
function objectToArray(data) {
	var arr = [];
	for (var key in data) {
		arr.push(key);
	}
	return arr;
}